@@ -4,7 +4,7 @@
  * Start Date:  Wed Nov 29 23:08:24 1995
  * Project:     INN (innfeed)
  * File:        endpoint.c
- * RCSId:       $Id: endpoint.c,v 1.9 1997/05/22 02:26:21 scrappy Exp $
+ * RCSId:       $Id: endpoint.c,v 1.10 1997/07/19 18:41:59 scrappy Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -38,7 +38,7 @@
  */
 
 #if ! defined (lint)
-static char rcsid [] = "$Id: endpoint.c,v 1.9 1997/05/22 02:26:21 scrappy Exp $" ;
+static char rcsid [] = "$Id: endpoint.c,v 1.10 1997/07/19 18:41:59 scrappy Exp $" ;
 static void use_rcsid (const char *rId) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rId) ;
 } 
@@ -1740,9 +1740,7 @@ void setSigHandler (int signum, void (*ptr)(int))
 static void handleSignals (void)
 {
   int i ;
-#if defined(USE_SIGACTION)
-  sigset_t set, oset ;
-#elif defined(USE_SIGVEC)
+#if defined(USE_SIGVEC)
   int mask ;
 #endif
 
