@@ -4,7 +4,7 @@
  * Start Date:  Sun Dec 31 18:52:04 1995
  * Project:     INN (innfeed)
  * File:        tape.c
- * RCSId:       $Id: tape.c,v 1.2 1997/04/30 19:18:30 scrappy Exp $
+ * RCSId:       $Id: tape.c,v 1.3 1997/07/19 18:42:13 scrappy Exp $
  *
  * Copyright:   Copyright (c) 1996 by Internet Software Consortium
  *
@@ -40,7 +40,7 @@
 
  
 #if ! defined (lint)
-static const char *rcsid = "$Id: tape.c,v 1.2 1997/04/30 19:18:30 scrappy Exp $" ;
+static const char *rcsid = "$Id: tape.c,v 1.3 1997/07/19 18:42:13 scrappy Exp $" ;
 static void use_rcsid (const char *rid) {   /* Never called */
   use_rcsid (rcsid) ; use_rcsid (rid) ;
 }
@@ -143,6 +143,9 @@ struct tape_s
 
     /* true if articles that are output are NOT later input. */
     bool noRotate ;     
+
+    /* true if no articles should ever be spooled */
+    bool noBacklog ;
 };
 
 
@@ -409,12 +412,20 @@ static void initTape (Tape nt)
   nt->outputSize = 0 ;
   nt->lossage = 0 ;
 
+  nt->noBacklog = false ;
   nt->backlogFactor = 0.0 ;
   nt->outputLowLimit = 0 ;
   nt->outputHighLimit = 0 ;
 
   if (!talkToSelf)
     {
+      int bval ;
+
+      if (getBool (s, "no-backlog", &bval, INHERIT))
+        nt->noBacklog = (bval ? true : false);
+      else
+        nt->noBacklog = TAPE_DISABLE;
+
       if (getInteger (s,"backlog-limit",&nt->outputLowLimit,INHERIT))
         {
           if (!getReal (s,"backlog-factor",&nt->backlogFactor,INHERIT))
@@ -435,6 +446,9 @@ static void initTape (Tape nt)
         syslog (LOG_ERR,NODEFN,"backlog-limit") ;
     }
   
+  dprintf (1, "%s spooling: %s\n", nt->peerName, 
+  	   nt->noBacklog ? "disabled" : "enabled");
+
   dprintf (1,"%s tape backlog limit: [%ld %ld]\n",nt->peerName,
            nt->outputLowLimit,
            nt->outputHighLimit) ;
@@ -505,6 +519,8 @@ void tapeLogStatus (Tape tape, FILE *fp)
 {
   if (tape == NULL)
     fprintf (fp,"(no tape)\n") ;
+  else if (tape->noBacklog)
+      fprintf (fp,"                 spooling: DISABLED\n");
   else 
     {
       fprintf (fp,"                 backlog low limit: %ld\n",
@@ -634,6 +650,10 @@ void tapeTakeArticle (Tape tape, Article article)
 
   ASSERT (tape != NULL) ;
 
+  /* return immediately if spooling disabled - jgarzik */
+  if (tape->noBacklog)
+    return;
+
   fname = artFileName (article) ;
   msgid = artMsgId (article) ;
   amt = fprintf (tape->outFp,"%s %s\n", fname, msgid) ;
